==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/sq.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Mungon fjalëkalim kyçi rimarrjesh",
    "Please repeat the recovery key password" : "Ju lutemi, rijepni fjalëkalimin për kyç rimarrjesh",
    "Repeated recovery key password does not match the provided recovery key password" : "Fjalëkalimi i ridhënë për kyç rimarrjesh s’përputhet me fjalëkalimin e dhënë për kyç rimarrjesh",
    "Recovery key successfully enabled" : "Kyçi i rimarrjeve u aktivizua me sukses",
    "Could not enable recovery key. Please check your recovery key password!" : "S’u aktivizua dot kyçi i rimarrjeve. Ju lutemi, kontrolloni fjalëkalimin për kyç rimarrjesh!",
    "Recovery key successfully disabled" : "Kyçi i rimarrjeve u çaktivizua me sukses",
    "Could not disable recovery key. Please check your recovery key password!" : "S’u çaktivizua dot kyçi i rimarrjeve. Ju lutemi, kontrolloni fjalëkalimin për kyç rimarrjesh!",
    "Missing parameters" : "Mungojnë parametra",
    "Please provide the old recovery password" : "Ju lutemi, jepni fjalëkalimin e vjetër të rimarrjes",
    "Please provide a new recovery password" : "Ju lutemi, jepni fjalëkalimin e ri të rimarrjes",
    "Please repeat the new recovery password" : "Ju lutemi, rijepni fjalëkalimin e ri të rimarrjes",
    "Password successfully changed." : "Fjalëkalimi u ndryshua me sukses.",
    "Could not change the password. Maybe the old password was not correct." : "Fjalëkalimi s’u ndryshua dot. Ndoshta fjalëkalimi i vjetër s’qe i saktë.",
    "Recovery Key disabled" : "Kyçi i Rimarrjeve u çaktivizua",
    "Recovery Key enabled" : "Kyçi i Rimarrjeve u aktivizua",
    "Could not enable the recovery key, please try again or contact your administrator" : "S’u aktivizua dot kyçi i rimarrjeve. ju lutemi, riprovoni ose lidhuni me përgjegjësin tuaj",
    "Could not update the private key password." : "Fjalëkalimi për kyçin privat s’u përditësua dot.",
    "The old password was not correct, please try again." : "Fjalëkalimi i vjetër s’qe i saktë, ju lutemi, riprovoni.",
    "The current log-in password was not correct, please try again." : "Fjalëkalimi i tanishëm i hyrjeve s’qe i saktë, ju lutemi, riprovoni.",
    "Private key password successfully updated." : "Fjalëkalimi për kyçin privat u përditësua me sukses.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Lypset të kaloni kyçet tuaj të fshehtëzimeve nga versioni i vjetër i fshehtëzimeve (ownCloud <= 8.0) te i riu. Ju lutemi, ekzekutoni run 'occ encryption:migrate' ose lidhuni me përgjegjësin tuaj",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Kyç privat i pavlefshëm për aplikacionin e fshehtëzimeve. Ju lutemi, përditësoni fjalëkalimin tuaj të kyçit privat te rregullimet tuaja personale që të rimerrni hyrje te kartelat tuaja të fshehtëzuara.",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacioni i fshehtëzimeve është i aktivizuar, por kyçet tuaj s’janë vënë në punë, ju lutemi, dilni dhe ribëni hyrjen",
    "Encryption app is enabled and ready" : "Aplikacioni i Fshehtëzimeve u aktivizua dhe është gati",
    "Bad Signature" : "Nënshkrim i Keq",
    "Missing Signature" : "Mungon Nënshkrimi",
    "one-time password for server-side-encryption" : "fjalëkalim vetëm për një herë, për fshehtëzim-më-anë-shërbyesi",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nuk shfshehtëzohet dot kjo kartelë, ndoshta është kartelë e ndarë me të tjerët. Ju lutemi, kërkojini të zotit të kartelës ta rindajë kartelën me ju.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "S’lexohet dot kjo kartelë, ndoshta është kartelë e ndarë me të tjerët. Ju lutemi, kërkojini të zotit të kartelës ta rindajë kartelën me ju.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Njatjeta,\n\npërgjegjësi aktivizoi fshehtëzim më anë shërbyesi. Kartelat tuaja qenë fshehtëzuar duke përdorur fjalëkalimin '%s'.\n\nJu lutemi, bëni hyrjen te ndërfaqja web, kaloni te ndarja 'modul i thjeshtëpër fshehtëzime' e rregullimeve tuaja personale dhe përditësoni fjalëkalimin tuaj për fshehtëzime duke dhënë këtë fjalëkalim te fusha 'old log-in password' dhe fjalëkalimin tuaj të tanishëm për hyrjet.\n\n",
    "The share will expire on %s." : "Ndarja do të skadojë më %s.",
    "Cheers!" : "Gëzuar!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Njatjeta,<br><br>përgjegjësi aktivizoi fshehtëzim më anë shërbyesi. Kartelat tuaja qenë fshehtëzuar duke përdorur fjalëkalimin <strong>%s</strong>.<br><br>Ju lutemi, bëni hyrjen te ndërfaqja web, kaloni te ndarja \"modul i thjeshtëpër fshehtëzime\" e rregullimeve tuaja personale dhe përditësoni fjalëkalimin tuaj për fshehtëzime duke dhënë këtë fjalëkalim te fusha \"old log-in password\" dhe fjalëkalimin tuaj të tanishëm për hyrjet.<br><br>",
    "Default encryption module" : "Modul i parazgjedhur fshehtëzimi",
    "Encrypt the home storage" : "Fshehtëzo depozitën bazë",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Aktivizimi i kësaj mundësie fshehtëzon krejt kartelat e depozituara në depon bazë, përndryshe do të fshehtëzohen vetëm kartelat në depozitën e jashtme",
    "Enable recovery key" : "Aktivizo kyç rimarrjesh",
    "Disable recovery key" : "Çaktivizo kyç rimarrjesh",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kyçi i rimarrjeve është një kyç ekstra fshehtëzimesh që përdoret për të fshehtëzuar kartela. Ai lejon rimarrjen e një kartele të përdoruesit, nëse përdoruesi harron fjalëkalimin e vet.",
    "Recovery key password" : "Fjalëkalim kyçi rimarrjesh",
    "Repeat recovery key password" : "Rijepni fjalëkalim kyçi rimarrjesh",
    "Change recovery key password:" : "Ndryshoni fjalëkalim kyçi rimarrjesh:",
    "Old recovery key password" : "Fjalëkalimi i vjetër kyçi rimarrjesh",
    "New recovery key password" : "Fjalëkalimi i ri kyçi rimarrjesh",
    "Repeat new recovery key password" : "Rijepni fjalëkalimin e ri kyçi rimarrjesh",
    "Change Password" : "Ndryshoni Fjalëkalimin",
    "Basic encryption module" : "Modul i thjeshtë fshehtëzimesh",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacioni i fshehtëzimeve është i aktivizuar, por kyçet tuaj s’janë vënë në punë, ju lutemi, dilni dhe ribëni hyrjen",
    "Your private key password no longer matches your log-in password." : "Fjalëkalimi juaj për kyçe privatë s’përputhet më me fjalëkalimin për hyrjet.",
    "Set your old private key password to your current log-in password:" : "Fjalëkalimit të vjetër të kyçit privat jepini vlerën e fjalëkalimit tuaj të tanishëm për hyrjet:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " Nëse s’e mbani mend fjalëkalimin tuaj të vjetër, mund t’i kërkoni përgjegjësit tuaj të rimarrë kartelat tuaja.",
    "Old log-in password" : "Fjalëkalimi i vjetër për hyrjet",
    "Current log-in password" : "Fjalëkalimi i tanishëm për hyrjet",
    "Update Private Key Password" : "Përditësoni Fjalëkalim Kyçi Privat",
    "Enable password recovery:" : "Aktivizo rimarrje fjalëkalimesh:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aktivizimi i kësaj mundësie do t’ju lejojë të rifitoni hyrje te kartelat tuaja të fshehtëzuara në rast humbjeje fjalëkalimi",
    "Enabled" : "E aktivizuar",
    "Disabled" : "E çaktivizuar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/sq.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Mungon fjalëkalim kyçi rimarrjesh",
    "Please repeat the recovery key password" : "Ju lutemi, rijepni fjalëkalimin për kyç rimarrjesh",
    "Repeated recovery key password does not match the provided recovery key password" : "Fjalëkalimi i ridhënë për kyç rimarrjesh s’përputhet me fjalëkalimin e dhënë për kyç rimarrjesh",
    "Recovery key successfully enabled" : "Kyçi i rimarrjeve u aktivizua me sukses",
    "Could not enable recovery key. Please check your recovery key password!" : "S’u aktivizua dot kyçi i rimarrjeve. Ju lutemi, kontrolloni fjalëkalimin për kyç rimarrjesh!",
    "Recovery key successfully disabled" : "Kyçi i rimarrjeve u çaktivizua me sukses",
    "Could not disable recovery key. Please check your recovery key password!" : "S’u çaktivizua dot kyçi i rimarrjeve. Ju lutemi, kontrolloni fjalëkalimin për kyç rimarrjesh!",
    "Missing parameters" : "Mungojnë parametra",
    "Please provide the old recovery password" : "Ju lutemi, jepni fjalëkalimin e vjetër të rimarrjes",
    "Please provide a new recovery password" : "Ju lutemi, jepni fjalëkalimin e ri të rimarrjes",
    "Please repeat the new recovery password" : "Ju lutemi, rijepni fjalëkalimin e ri të rimarrjes",
    "Password successfully changed." : "Fjalëkalimi u ndryshua me sukses.",
    "Could not change the password. Maybe the old password was not correct." : "Fjalëkalimi s’u ndryshua dot. Ndoshta fjalëkalimi i vjetër s’qe i saktë.",
    "Recovery Key disabled" : "Kyçi i Rimarrjeve u çaktivizua",
    "Recovery Key enabled" : "Kyçi i Rimarrjeve u aktivizua",
    "Could not enable the recovery key, please try again or contact your administrator" : "S’u aktivizua dot kyçi i rimarrjeve. ju lutemi, riprovoni ose lidhuni me përgjegjësin tuaj",
    "Could not update the private key password." : "Fjalëkalimi për kyçin privat s’u përditësua dot.",
    "The old password was not correct, please try again." : "Fjalëkalimi i vjetër s’qe i saktë, ju lutemi, riprovoni.",
    "The current log-in password was not correct, please try again." : "Fjalëkalimi i tanishëm i hyrjeve s’qe i saktë, ju lutemi, riprovoni.",
    "Private key password successfully updated." : "Fjalëkalimi për kyçin privat u përditësua me sukses.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Lypset të kaloni kyçet tuaj të fshehtëzimeve nga versioni i vjetër i fshehtëzimeve (ownCloud <= 8.0) te i riu. Ju lutemi, ekzekutoni run 'occ encryption:migrate' ose lidhuni me përgjegjësin tuaj",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Kyç privat i pavlefshëm për aplikacionin e fshehtëzimeve. Ju lutemi, përditësoni fjalëkalimin tuaj të kyçit privat te rregullimet tuaja personale që të rimerrni hyrje te kartelat tuaja të fshehtëzuara.",
    "Encryption app is enabled and ready" : "Aplikacioni i Fshehtëzimeve u aktivizua dhe është gati",
    "Bad Signature" : "Nënshkrim i Keq",
    "Missing Signature" : "Mungon Nënshkrimi",
    "one-time password for server-side-encryption" : "fjalëkalim vetëm për një herë, për fshehtëzim-më-anë-shërbyesi",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nuk shfshehtëzohet dot kjo kartelë, ndoshta është kartelë e ndarë me të tjerët. Ju lutemi, kërkojini të zotit të kartelës ta rindajë kartelën me ju.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "S’lexohet dot kjo kartelë, ndoshta është kartelë e ndarë me të tjerët. Ju lutemi, kërkojini të zotit të kartelës ta rindajë kartelën me ju.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Njatjeta,\n\npërgjegjësi aktivizoi fshehtëzim më anë shërbyesi. Kartelat tuaja qenë fshehtëzuar duke përdorur fjalëkalimin '%s'.\n\nJu lutemi, bëni hyrjen te ndërfaqja web, kaloni te ndarja 'modul i thjeshtëpër fshehtëzime' e rregullimeve tuaja personale dhe përditësoni fjalëkalimin tuaj për fshehtëzime duke dhënë këtë fjalëkalim te fusha 'old log-in password' dhe fjalëkalimin tuaj të tanishëm për hyrjet.\n\n",
    "The share will expire on %s." : "Ndarja do të skadojë më %s.",
    "Cheers!" : "Gëzuar!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Njatjeta,<br><br>përgjegjësi aktivizoi fshehtëzim më anë shërbyesi. Kartelat tuaja qenë fshehtëzuar duke përdorur fjalëkalimin <strong>%s</strong>.<br><br>Ju lutemi, bëni hyrjen te ndërfaqja web, kaloni te ndarja \"modul i thjeshtëpër fshehtëzime\" e rregullimeve tuaja personale dhe përditësoni fjalëkalimin tuaj për fshehtëzime duke dhënë këtë fjalëkalim te fusha \"old log-in password\" dhe fjalëkalimin tuaj të tanishëm për hyrjet.<br><br>",
    "Default encryption module" : "Modul i parazgjedhur fshehtëzimi",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacioni i fshehtëzimeve është i aktivizuar, por kyçet tuaj s’janë vënë në punë, ju lutemi, dilni dhe ribëni hyrjen",
    "Encrypt the home storage" : "Fshehtëzo depozitën bazë",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Aktivizimi i kësaj mundësie fshehtëzon krejt kartelat e depozituara në depon bazë, përndryshe do të fshehtëzohen vetëm kartelat në depozitën e jashtme",
    "Enable recovery key" : "Aktivizo kyç rimarrjesh",
    "Disable recovery key" : "Çaktivizo kyç rimarrjesh",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kyçi i rimarrjeve është një kyç ekstra fshehtëzimesh që përdoret për të fshehtëzuar kartela. Ai lejon rimarrjen e një kartele të përdoruesit, nëse përdoruesi harron fjalëkalimin e vet.",
    "Recovery key password" : "Fjalëkalim kyçi rimarrjesh",
    "Repeat recovery key password" : "Rijepni fjalëkalim kyçi rimarrjesh",
    "Change recovery key password:" : "Ndryshoni fjalëkalim kyçi rimarrjesh:",
    "Old recovery key password" : "Fjalëkalimi i vjetër kyçi rimarrjesh",
    "New recovery key password" : "Fjalëkalimi i ri kyçi rimarrjesh",
    "Repeat new recovery key password" : "Rijepni fjalëkalimin e ri kyçi rimarrjesh",
    "Change Password" : "Ndryshoni Fjalëkalimin",
    "Basic encryption module" : "Modul i thjeshtë fshehtëzimesh",
    "Your private key password no longer matches your log-in password." : "Fjalëkalimi juaj për kyçe privatë s’përputhet më me fjalëkalimin për hyrjet.",
    "Set your old private key password to your current log-in password:" : "Fjalëkalimit të vjetër të kyçit privat jepini vlerën e fjalëkalimit tuaj të tanishëm për hyrjet:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " Nëse s’e mbani mend fjalëkalimin tuaj të vjetër, mund t’i kërkoni përgjegjësit tuaj të rimarrë kartelat tuaja.",
    "Old log-in password" : "Fjalëkalimi i vjetër për hyrjet",
    "Current log-in password" : "Fjalëkalimi i tanishëm për hyrjet",
    "Update Private Key Password" : "Përditësoni Fjalëkalim Kyçi Privat",
    "Enable password recovery:" : "Aktivizo rimarrje fjalëkalimesh:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aktivizimi i kësaj mundësie do t’ju lejojë të rifitoni hyrje te kartelat tuaja të fshehtëzuara në rast humbjeje fjalëkalimi",
    "Enabled" : "E aktivizuar",
    "Disabled" : "E çaktivizuar",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacioni i fshehtëzimeve është i aktivizuar, por kyçet tuaj s’janë vënë në punë, ju lutemi, dilni dhe ribëni hyrjen"
},
"nplurals=2; plural=(n != 1);");
